/****************************************************
*                    Projet CLIP                    *
****************************************************/

/*------------------------------------------------------------------------------------
  Nom          :  MSP_1232_Test_3310.c
  Description  :  Programme de test routines LCD
  Author       :  21/05/2006 - CREMMEL Marcel
  History      :  21/05/2006 - Premire version
--------------------------------------------------------------------------------------*/
#include <msp430x12x2.h>
#include <stdbool.h> // Pour le type "bool"
#include <stdlib.h>  // Pour le type div_t

/*------------------------------------------------------------------------------------
                                    Dfinition de type
--------------------------------------------------------------------------------------*/
typedef enum
{
    Lcd_Cmd  = 0,
    Lcd_Data = 1
} LcdCmdData; // Type de transfert : commande ou donnes

typedef enum
{
    Blanc = 0,
    Noir  = 1
} Couleur; // Type de couleur

/*------------------------------------------------------------------------------------
                                         Constantes
--------------------------------------------------------------------------------------*/

/*------------------
       Cblage
--------------------*/
// Ports SPI
#define Lcd_DIN_Pin BIT1  //  P3.1 = SOMI = SDIN
#define Lcd_CLK_Pin BIT3  //  P3.3 = UCLK = SCLK

// Connexions LCD Nokia (transmission via SPI)
#define Lcd_CE_Pin  BIT0  //  P3.0 = CE_LCD
#define Lcd_DC_Pin  BIT2  //  P3.2 = D/C
#define Lcd_RST_Pin BIT2  //  P2.2 = RESET_LCD

/*-------------------------
  Constantes LCD Nokia 3310
---------------------------*/
#define Lcd_X_res       84
#define Lcd_Y_res       48
// Commandes controleur PCD8544
#define Function_Set    0x20    //Bit 2 = PD, Bit 1 = V, Bit 1 = H
#define Lcd_ON_Norm_H   0x20    //Lcd actif, adressage H, mode normal
#define Lcd_ON_Norm_V   0x22    //Lcd actif, adressage V, mode normal
#define Lcd_ON_Etendu_H 0x21    //Lcd actif, adressage H, mode tendu (H=1)
#define Lcd_OFF_Norm_H  0x24    //Lcd "power down", adressage H, mode normal
// Commandes normales (bit H="0")
#define Set_Config      0x08    //Bit 2 = D, bit 0 = E
#define Set_Adr_Y       0x40    //Adresse Y dans 3 bits LSB (0  5)
#define Set_Adr_X       0x80    //Adresse X dans 7 bits LSB (0  83)
// Commandes tendues (bit H="1")
#define Set_Bias        0x10    //Bias Mode dans bits 2  0
#define Set_Vop         0x80    //Vop dans bits 6  0
#define Set_TC          0x04    //Coef de temprature dans bits 1  0
// Positions des paramtres sur le LCD
#define Pos_FRX_X       5       //Position X de la frquence de rception (0  83)
#define Pos_FRX_Y       2       //Position Y de la frquence de rception (0  5)
#define Pos_Filtre_X    41      //Position X de la frquence de rception (0  83)
#define Pos_Filtre_Y    4       //Position Y de la frquence de rception (0  5)

/*------------------------------------------------------------------------------------
                                    Variables globales
-------------------------------------------------------------------------------------*/
/*-----------------
        LCD
-------------------*/
char Adr_X ;// Copie logicielle de l'adresse X du PCD8544 (0  83)
char Adr_Y ;// Copie logicielle de l'adresse Y du PCD8544 (0  5)

/*------------------------------------------------------------------------------------
                                 Constantes en mmoire flash
-------------------------------------------------------------------------------------*/
/* ---------------------
   Polices de caractres
   ---------------------
Gnrateur de caractre en mmoire flash
Code Ascii, format 5x7 pixels.
Format : Y    X   1   2   3   4   5
         1       D10 D20 D30 D40 D50
         2       D11 D21 D31 D41 D51
         3       D12 D22 D32 D42 D52
         4       D13 D23 D33 D43 D53
         5       D14 D24 D34 D44 D54
         6       D15 D25 D35 D45 D55
         7       D16 D26 D36 D46 D56
1 octet : D16-D15-D14-D13-D12-D11-D10, bit 7 toujours  "0"
2 octet : D26-D25-D24-D23-D22-D21-D20, bit 7 toujours  "0"
3 octet : D36-D35-D34-D33-D32-D31-D30, bit 7 toujours  "0"
4 octet : D46-D45-D44-D43-D42-D41-D40, bit 7 toujours  "0"
5 octet : D56-D55-D54-D53-D52-D51-D50, bit 7 toujours  "0"
--------------------------------------------------------------------------------------*/
const char FontLookup[][5] =
{
    { 0x00, 0x00, 0x00, 0x00, 0x00 },   // sp
    { 0x00, 0x00, 0x2f, 0x00, 0x00 },   // !
    { 0x00, 0x07, 0x00, 0x07, 0x00 },   // "
    { 0x14, 0x7f, 0x14, 0x7f, 0x14 },   // #
    { 0x24, 0x2a, 0x7f, 0x2a, 0x12 },   // $
    { 0xc4, 0xc8, 0x10, 0x26, 0x46 },   // %
    { 0x36, 0x49, 0x55, 0x22, 0x50 },   // &
    { 0x00, 0x05, 0x03, 0x00, 0x00 },   // '
    { 0x00, 0x1c, 0x22, 0x41, 0x00 },   // (
    { 0x00, 0x41, 0x22, 0x1c, 0x00 },   // )
    { 0x14, 0x08, 0x3E, 0x08, 0x14 },   // *
    { 0x08, 0x08, 0x3E, 0x08, 0x08 },   // +
    { 0x00, 0x00, 0x50, 0x30, 0x00 },   // ,
    { 0x10, 0x10, 0x10, 0x10, 0x10 },   // -
    { 0x00, 0x60, 0x60, 0x00, 0x00 },   // .
    { 0x20, 0x10, 0x08, 0x04, 0x02 },   // /
    { 0x3E, 0x51, 0x49, 0x45, 0x3E },   // 0
    { 0x00, 0x42, 0x7F, 0x40, 0x00 },   // 1
    { 0x42, 0x61, 0x51, 0x49, 0x46 },   // 2
    { 0x21, 0x41, 0x45, 0x4B, 0x31 },   // 3
    { 0x18, 0x14, 0x12, 0x7F, 0x10 },   // 4
    { 0x27, 0x45, 0x45, 0x45, 0x39 },   // 5
    { 0x3C, 0x4A, 0x49, 0x49, 0x30 },   // 6
    { 0x01, 0x71, 0x09, 0x05, 0x03 },   // 7
    { 0x36, 0x49, 0x49, 0x49, 0x36 },   // 8
    { 0x06, 0x49, 0x49, 0x29, 0x1E },   // 9
    { 0x00, 0x36, 0x36, 0x00, 0x00 },   // :
    { 0x00, 0x56, 0x36, 0x00, 0x00 },   // ;
    { 0x08, 0x14, 0x22, 0x41, 0x00 },   // <
    { 0x14, 0x14, 0x14, 0x14, 0x14 },   // =
    { 0x00, 0x41, 0x22, 0x14, 0x08 },   // >
    { 0x02, 0x01, 0x51, 0x09, 0x06 },   // ?
    { 0x32, 0x49, 0x59, 0x51, 0x3E },   // @
    { 0x7E, 0x11, 0x11, 0x11, 0x7E },   // A
    { 0x7F, 0x49, 0x49, 0x49, 0x36 },   // B
    { 0x3E, 0x41, 0x41, 0x41, 0x22 },   // C
    { 0x7F, 0x41, 0x41, 0x22, 0x1C },   // D
    { 0x7F, 0x49, 0x49, 0x49, 0x41 },   // E
    { 0x7F, 0x09, 0x09, 0x09, 0x01 },   // F
    { 0x3E, 0x41, 0x49, 0x49, 0x7A },   // G
    { 0x7F, 0x08, 0x08, 0x08, 0x7F },   // H
    { 0x00, 0x41, 0x7F, 0x41, 0x00 },   // I
    { 0x20, 0x40, 0x41, 0x3F, 0x01 },   // J
    { 0x7F, 0x08, 0x14, 0x22, 0x41 },   // K
    { 0x7F, 0x40, 0x40, 0x40, 0x40 },   // L
    { 0x7F, 0x02, 0x0C, 0x02, 0x7F },   // M
    { 0x7F, 0x04, 0x08, 0x10, 0x7F },   // N
    { 0x3E, 0x41, 0x41, 0x41, 0x3E },   // O
    { 0x7F, 0x09, 0x09, 0x09, 0x06 },   // P
    { 0x3E, 0x41, 0x51, 0x21, 0x5E },   // Q
    { 0x7F, 0x09, 0x19, 0x29, 0x46 },   // R
    { 0x46, 0x49, 0x49, 0x49, 0x31 },   // S
    { 0x01, 0x01, 0x7F, 0x01, 0x01 },   // T
    { 0x3F, 0x40, 0x40, 0x40, 0x3F },   // U
    { 0x1F, 0x20, 0x40, 0x20, 0x1F },   // V
    { 0x3F, 0x40, 0x38, 0x40, 0x3F },   // W
    { 0x63, 0x14, 0x08, 0x14, 0x63 },   // X
    { 0x07, 0x08, 0x70, 0x08, 0x07 },   // Y
    { 0x61, 0x51, 0x49, 0x45, 0x43 },   // Z
    { 0x00, 0x7F, 0x41, 0x41, 0x00 },   // [
    { 0x55, 0x2A, 0x55, 0x2A, 0x55 },   // 55
    { 0x00, 0x41, 0x41, 0x7F, 0x00 },   // ]
    { 0x04, 0x02, 0x01, 0x02, 0x04 },   // ^
    { 0x40, 0x40, 0x40, 0x40, 0x40 },   // _
    { 0x00, 0x01, 0x02, 0x04, 0x00 },   // '
    { 0x20, 0x54, 0x54, 0x54, 0x78 },   // a
    { 0x7F, 0x48, 0x44, 0x44, 0x38 },   // b
    { 0x38, 0x44, 0x44, 0x44, 0x20 },   // c
    { 0x38, 0x44, 0x44, 0x48, 0x7F },   // d
    { 0x38, 0x54, 0x54, 0x54, 0x18 },   // e
    { 0x08, 0x7E, 0x09, 0x01, 0x02 },   // f
    { 0x0C, 0x52, 0x52, 0x52, 0x3E },   // g
    { 0x7F, 0x08, 0x04, 0x04, 0x78 },   // h
    { 0x00, 0x44, 0x7D, 0x40, 0x00 },   // i
    { 0x20, 0x40, 0x44, 0x3D, 0x00 },   // j
    { 0x7F, 0x10, 0x28, 0x44, 0x00 },   // k
    { 0x00, 0x41, 0x7F, 0x40, 0x00 },   // l
    { 0x7C, 0x04, 0x18, 0x04, 0x78 },   // m
    { 0x7C, 0x08, 0x04, 0x04, 0x78 },   // n
    { 0x38, 0x44, 0x44, 0x44, 0x38 },   // o
    { 0x7C, 0x14, 0x14, 0x14, 0x08 },   // p
    { 0x08, 0x14, 0x14, 0x18, 0x7C },   // q
    { 0x7C, 0x08, 0x04, 0x04, 0x08 },   // r
    { 0x48, 0x54, 0x54, 0x54, 0x20 },   // s
    { 0x04, 0x3F, 0x44, 0x40, 0x20 },   // t
    { 0x3C, 0x40, 0x40, 0x20, 0x7C },   // u
    { 0x1C, 0x20, 0x40, 0x20, 0x1C },   // v
    { 0x3C, 0x40, 0x30, 0x40, 0x3C },   // w
    { 0x44, 0x28, 0x10, 0x28, 0x44 },   // x
    { 0x0C, 0x50, 0x50, 0x50, 0x3C },   // y
    { 0x44, 0x64, 0x54, 0x4C, 0x44 }    // z
};

/*--------------------------------------
Gnrateur de caractres : chiffres 0  9
Nombre de caractres : 10
Rsolution X : 10
Rsolution Y : 14 */
const char MyFontTab[][10] =
{
    { 252, 254,   3,   3,   3,   3,   3,   3, 254, 252  }, // 0 octet LSB
    {   0,  16,  24,  12,   6, 255, 255,   0,   0,   0  }, // 1 octet LSB
    {   2,   3, 131, 131, 131, 131, 131, 195, 254, 124  }, // 2 octet LSB
    {   2,   3,   3, 195, 195, 195, 195, 199, 254,  60  }, // 3 octet LSB
    { 192, 224,  48,  24,  12, 198, 195,   1,   0,   0  }, // 4 octet LSB
    {  31,  63,  99,  99,  99,  99,  99,  99, 195, 131  }, // 5 octet LSB
    { 252, 254, 195, 195, 195, 195, 195, 195, 131,   0  }, // 6 octet LSB
    {   2,   3,   3,   3, 131, 195,  99,  51,  31,  15  }, // 7 octet LSB
    { 124, 254, 195, 195, 195, 195, 195, 195, 254,  60  }, // 8 octet LSB
    { 124, 254, 195, 195, 195, 195, 195, 195, 254, 252  }, // 9 octet LSB
    {  15,  31,  48,  48,  48,  48,  48,  48,  31,  15  }, // 0 octet MSB
    {   0,   0,   0,  48,  48,  63,  63,  48,  48,   0  }, // 1 octet MSB
    {  62,  63,  51,  49,  49,  49,  49,  49,  48,  48  }, // 2 octet MSB
    {  16,  48,  48,  48,  48,  48,  48,  56,  31,  15  }, // 3 octet MSB
    {   3,   3,   3,   3,   3,  63,  63,   3,   3,   3  }, // 4 octet MSB
    {  16,  48,  48,  48,  48,  48,  48,  48,  31,  15  }, // 5 octet MSB
    {  15,  31,  48,  48,  48,  48,  48,  48,  31,  15  }, // 6 octet MSB
    {  56,  60,   6,   3,   1,   0,   0,   0,   0,   0  }, // 7 octet MSB
    {  15,  31,  48,  48,  48,  48,  48,  48,  31,  15  }, // 8 octet MSB
    {   0,  48,  48,  48,  48,  48,  48,  48,  31,  15  }  // 9 octet MSB
};

/*--------------------------------------
          Image d'accueil
  --------------------------------------*/
const char Image_Accueil[] =
{
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0, 128, 224, 240, 248,  56,  28,  28,  28,  28,
  28,  60,  56, 120, 112,  32,   0,   0,   0, 252, 252, 252,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
 252, 252, 252,   0,   0,   0,   0, 252, 252, 252,  28,  28,
  28,  28,  28,  28,  60, 248, 248, 224,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,  63, 255, 255, 224, 128,   0,   0,   0,   0,
   0, 128, 128, 192, 192, 128,   0,   0,   0, 255, 255, 255,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
 255, 255, 255,   0,   0,   0,   0, 255, 255, 255,  28,  28,
  28,  28,  28,  28,  30,  15,   7,   3,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   1,   3,   3,   7,   7,   7,   7,
   7,   7,   3,   3,   1,   0,   0,   0,   0,   7,   7,   7,
   7,   7,   7,   7,   7,   7,   7,   7,   7,   0,   0,   0,
   7,   7,   7,   0,   0,   0,   0,   7,   7,   7,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0, 128, 112,  46,  33,  46, 112, 132, 255,   5,   4, 255,
   5,   0, 253,   0, 248,   4,   4, 136,   0, 255,   8,   4,
   4, 248,   0, 200,  36,  36,  36, 248,   0, 248,   4,   4,
 136, 252,   0, 248,  36,  36,  36, 184,   0,   0,   0,   0,
 248,   4,   4, 136, 255,   0, 252,   0,   0, 128, 252,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0, 192, 128,  64,  64, 128,   0, 192,   0,   0,   0,
 192,   1, 192, 128,  64, 128, 128,  65, 129,   0,   0, 129,
  64,  80,  73, 128,   0, 193, 129,  64,   0, 129,  64,  64,
  64, 129,   0,   0,   1,   1, 129,  65,  64,  68, 137,   9,
 200, 135,  64,  64, 129,   1, 193, 128,  64,  64, 128,   0,
 128,  65,  65,  64, 129,   0, 240,   1, 129,  64,  65,  64,
 128,   0, 192, 128,  64,  64, 128,  64, 240,  64,   0,   0,
   0,   0,  31,   0,   0,   0,  31,   0,  15,  16,  16,   8,
  31,   0,  31,   0,   0,  31,   0,   0,  31,   0,   0,  15,
  18,  18,  18,  11,   0,  31,   0,   0,   0,  15,  16,  16,
  16,  15,   0,   0,   0,   0,  12,  18,  18,  18,  31,   0,
 255,   8,  16,  16,  15,   0, 255,   8,  16,  16,  15,   0,
  15,  18,  18,  18,  11,   0,  31,   0,  12,  18,  18,  18,
  31,   0,  31,   0,   0,   0,  31,   0,  31,  16,   0,   0
};

/*------------------------------------------------------------------------------------
                                        HORLOGES
---------------------------------------------------------------------------------------*/

/*--------------------------------------------------
  Nom          :  SetDCOClock
  Description  :  Affectation frquence DCO
  Arguments    :  DCO : valeur des 3 bits DCO
                  RES : valeur des 3 bits RESEL
  Valeur renvoye : aucune.
----------------------------------------------------*/
void SetDCOClock(int DCO,int RES)
{
  DCOCTL=(DCOCTL & ~(DCO2|DCO1|DCO0)) | (DCO << 5); //Affectation DCO[2..0]
  BCSCTL1=(BCSCTL1 & ~(RSEL2|RSEL1|RSEL0)) | RES  ; //Affectation RESEL[2..0]
}

/*------------------------------------------------------------------------------------
                                   Fonctions de gestion du LCD
--------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------
  Nom          :  InitSPI_Lcd
  Description  :  Initialisation du coupleur SPI
                  Il est utilis pour la transmission vers le LCD
  Arguments    :  aucun
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void InitSPI_Lcd(void)
{
  U0CTL=SWRST; //SWRST = "1" pour configurer l'USART en mode SPI
  U0CTL=SWRST|CHAR|SYNC|MM; //Mode Master SPI 8 bits
  U0TCTL=CKPH|SSEL1|STC; //CKPH/CKPL=10 : format PCD8544
                         //SSEL=10 : SMCLK
                         //STC=1 : STE inhib
  U0BR0=4; //
  U0BR1=0; // U0BR = 4 : Baud rate = SMCLK/4
  U0MCTL=0; //Impos en mode SPI
  ME2|=USPIE0; //Validation SPI
  U0CTL&=~SWRST; //SWRST = "0" fin de configuration
  P3SEL|=Lcd_DIN_Pin|Lcd_CLK_Pin;
}

/*---------------------------------------------------------------
  Nom          :  CloseSPI_Lcd
  Description  :  Dsactivation du coupleur SPI
  Arguments    :  aucun
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void CloseSPI_Lcd(void)
{
  U0CTL&=~SYNC; //Arrt SPI
  P3SEL&=~(Lcd_DIN_Pin|Lcd_CLK_Pin);
  P3DIR|=Lcd_DIN_Pin|Lcd_CLK_Pin; //Gestion LCD sans coupleur SPI
}

/*---------------------------------------------------------------
  Nom          :  LcdSend_NoSPI
  Description  :  Envoi d'un octet vers le controleur du LCD
                  sans utiliser le coupleur SPI
  Arguments    :  data -> Donne ou commande  transmettre
                  cd   -> Type de transfert : commande (Lcd_Cmd) ou donne (Lcd_Data)
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void LcdSend_NoSPI(char Data, LcdCmdData CD)
{
  int i;
  if (CD == Lcd_Data) P3OUT |=  Lcd_DC_Pin;
                 else P3OUT &= ~Lcd_DC_Pin;
  // Transmission srie de l'octet
  for (i=0; i<8; i++)
  {
   if ((Data & 0x80)==0) P3OUT &= ~Lcd_DIN_Pin;
                    else P3OUT |=  Lcd_DIN_Pin;
   Data <<= 1;
   P3OUT |=  Lcd_CLK_Pin;
   P3OUT &= ~Lcd_CLK_Pin;
  }
}

/*---------------------------------------------------------------
  Nom          :  LcdSend
  Description  :  Envoi d'un octet vers le controleur du LCD via coupleur SPI
  Arguments    :  data -> Donne ou commande  transmettre
                  cd   -> Type de transfert : commande (Lcd_Cmd) ou donne (Lcd_Data)
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void LcdSend(char Data, LcdCmdData CD)
{
 if ((U0CTL & SYNC)==0) LcdSend_NoSPI(Data,CD);//Sortie sans coupleur SPI ?
 else // avec coupleur SPI
  {
   // Attendre fin de transmission
   while ((U0TCTL & TXEPT)==0) {};
   // Affectation signal D/C
   if (CD == Lcd_Data) P3OUT |=  Lcd_DC_Pin;
                  else P3OUT &= ~Lcd_DC_Pin;
   // Transmission srie de l'octet
   U0TXBUF=Data;
  }
}

/*---------------------------------------------------------------
  Nom          :  Delay
  Description  :  Production d'un dlai logiciel
  Arguments    :  aucun
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void Delay(int Delai)
{
  int i;
  for ( i = -Delai; i < Delai; i++ );
}

/*---------------------------------------------------------------
  Nom          :  LcdInit
  Description  :  Initialisation du PCD8544
  Arguments    :  aucun
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
// Note : la commande de contraste est sans effet
void LcdInit(void)
{
  P3OUT |= Lcd_CE_Pin ; // Controleur non slectionn (CE = "1")
  P2OUT |= Lcd_RST_Pin; // et pas de reset (RST = "1")
  Delay(3000); // Dlai de xx5s environ
  P2OUT &= ~Lcd_RST_Pin; //Reset PCD8544 (RST = "0")
  Delay(3000); // Dlai de xxs environ
  P2OUT |= Lcd_RST_Pin; //Arrt reset PCD8544 (RST = "1")
  Adr_X=0; Adr_Y=0;
  // Slection du controleur (actif  "0").
  P3OUT &= ~Lcd_CE_Pin; // CE = "0"
  LcdSend(Lcd_ON_Etendu_H, Lcd_Cmd); //Mode commandes tendues
  // LcdSend(Set_Vop+72,Lcd_Cmd); //Set LCD Vop (contrast)
  // LcdSend(Set_TC+2,Lcd_Cmd);   //Set temp. coefficient
  LcdSend(Set_Bias+3,Lcd_Cmd);    //LCD Bias mode 1:48
  LcdSend(Lcd_ON_Norm_H,Lcd_Cmd); //LCD standard commands. Horizontal addressing mode.
  LcdSend(Set_Config+4,Lcd_Cmd);  //LCD in normal mode (DE = 10)
}

/*---------------------------------------------------------------
  Nom          :  LcdGotoXY
  Description  :  Affecter les adresses X et Y du PCD8544
  Arguments    :  X : position H (0  83)
                  Y : position V (0  5)
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void LcdGotoXY(char x, char y)
{
  Adr_X=x; Adr_Y=y;
  LcdSend(Set_Adr_X+Adr_X,Lcd_Cmd); //Affectation adresse X
  LcdSend(Set_Adr_Y+Adr_Y,Lcd_Cmd); //Affectation adresse Y
}

/*---------------------------------------------------------------
  Nom          :  Fill_Lcd
  Description  :  Remplir le LCD de la mme couleur
  Arguments    :  Coul_Lcd : Noir ou Blanc
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void Fill_Lcd(Couleur Coul_Lcd)
{
 int x,y;
 char b;
 if (Coul_Lcd==Noir) b=255;
                else b=0;
 for (y=0; y<Lcd_Y_res/8+1; y++)
  {
   LcdGotoXY(0,y);
   for (x=0; x<Lcd_X_res; x++) LcdSend(b,Lcd_Data);
  }
 LcdGotoXY(0,0);
}

/*---------------------------------------------------------------
  Nom          :  LcdChar
  Description  :  Dessin d'un caractre  la position actuelle des compteurs X et Y
  Arguments    :  Code Ascii du caractre
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void LcdChar(char c)
{
 int i;
 if (c < ' ') c=c+'a';
 if (c >= 0x80) c=c-0x80+'A';
 for (i=0; i<5; i++) LcdSend(FontLookup[c-32][i],Lcd_Data);
 Adr_X += 5;
}

/*---------------------------------------------------------------
  Nom          :  LcdString
  Description  :  Dessin d'une phrase  la position actuelle des compteurs X et Y
  Arguments    :  Pointeur de la chane de caractres
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void LcdString(char X, char Y, char *Phrase)
{
 LcdGotoXY(X,Y);
 while (*Phrase)
  {
   LcdChar(*Phrase++);
   LcdSend(0,Lcd_Data); // Espace inter-caractres
   Adr_X++;
   if (Adr_X > Lcd_X_res-5)
    {
     LcdGotoXY(0,Y+1);
    }
  }
}

/*---------------------------------------------------------------
  Nom          :  LcdBigDigit
  Description  :  Dessin d'un chiffre 14x10 pixels  la position actuelle des
                  compteurs X et Y
  Arguments    :  Chiffre cod BCD
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void LcdBigDigit(char b)
{
 int i;
 for (i=0; i<10; i++) LcdSend(MyFontTab[b][i],Lcd_Data); // D'abord les octets LSB
 LcdSend(Set_Adr_X+Adr_X,Lcd_Cmd);   // Retour au dbut du dessin
 LcdSend(Set_Adr_Y+Adr_Y+1,Lcd_Cmd); // Octets MSB  la ligne de 8 pixels infrieure
 for (i=0; i<10; i++) LcdSend(MyFontTab[b+10][i],Lcd_Data); // Puis les octets MSB
 Adr_X += 12;
 LcdSend(Set_Adr_Y+Adr_Y,Lcd_Cmd); //Prochain chiffre sur la mme ligne
 LcdSend(Set_Adr_X+Adr_X,Lcd_Cmd); //et 12 pixels  droite
}

/*---------------------------------------------------------------
  Nom          :  LcdBigString
  Description  :  Dessin d'une suite de chiffres  la position actuelle
                  des compteurs X et Y
  Arguments    :  Pointeur de la chane de caractres
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void LcdBigString(char *Chaine)
{
 while (*Chaine) LcdBigDigit(*Chaine++ - '0');
}

/*---------------------------------------------------------------
  Nom          :  ClearLineLcd
  Description  :  Effacer une ligne du LCD
  Arguments    :  X ,Y : position initiale (X:0  83 et Y:0  5)
                  LngLine : longueur de la ligne en pixels
  Valeur renvoye : aucune.
-----------------------------------------------------------------*/
void ClearLineLcd(char X, char Y, char LngLine)
{
 int i;
 LcdGotoXY(X,Y);
 for (i=0; i<LngLine; i++) LcdSend(0,Lcd_Data);
}

/*---------------------------------------------------------------
  Nom          :  ImageLcd
  Description  :  Afficher une image sur le LCD
  Arguments    :  Aucun
  Valeur renvoye : Aucune.
-----------------------------------------------------------------*/
void ImageLcd(void)
{
 int x,y;
 for (y=0; y<Lcd_Y_res/8+1; y++)
  {
   LcdGotoXY(0,y);
   for (x=0; x<Lcd_X_res; x++) LcdSend(Image_Accueil[x+y*Lcd_X_res],Lcd_Data);
  }
 LcdGotoXY(0,0);
}

/*------------------------------------------------------------------------------------
                                       Programme principal
--------------------------------------------------------------------------------------*/
void main(void)
{
 WDTCTL=WDTPW+WDTHOLD;       // Arrt du chien de garde
 // Horloge basse
 SetDCOClock(3,1); // FDCO = 190kHz typique
 // Initialisations ports E/S
 P2DIR=Lcd_RST_Pin; // Port 2
 P3DIR=Lcd_CE_Pin|Lcd_DIN_Pin|Lcd_CLK_Pin|Lcd_DC_Pin;//Port 3
 P3OUT=Lcd_CE_Pin;// Controleur LCD et CNA non slectionns
 P2OUT=Lcd_RST_Pin; // Pas de reset (RST = "1") et PWR_ON = "0"
 // Initialisation USART en mode SPI (pour affichage initial)
 //InitSPI_Lcd();//Initialisation du coupleur SPI pour Lcd
 LcdInit();    //Initialisation controleur Lcd
 ImageLcd();   //Ecran d'accueil
 Delay(32000);Delay(32000);Delay(32000);Delay(32000);Delay(32000);
 Fill_Lcd(Blanc);
 LcdString(10,0,"Transverter");
 LcdString(4,1,"decametrique");
 LcdGotoXY(5,2) ;LcdBigString("10");
 LcdGotoXY(31,3);LcdChar('a');
 LcdGotoXY(40,2);LcdBigString("20");
 LcdString(65,3,"MHz");
 LcdString(0,5,"Filtre:");
 LcdString(56,4,"PLL:");
 LcdString(56,5,"LOCK");

/*-------------------
   Boucle principale
 --------------------*/
 for (;;) {}
}
